```
Usage: vcd system [OPTIONS] COMMAND [ARGS]...

  Manage system settings in vCloud Director.



Options:
  -h, --help  Show this message and exit.

Commands:
  amqp       manage AMQP settings
  extension  manage extension services
  info       show system details

```
